/**
 * Ionicons icon set component.
 * Usage: <Ionicons name="icon-name" size={20} color="#4F8EF7" />
 *
 * @providesModule Ionicons
 */
'use strict';

var createIconSet = require('./lib/create-icon-set');
var glyphMap = {
  "alert": 61697,
  "alert-circled": 61696,
  "android-add": 62151,
  "android-add-circle": 62297,
  "android-alarm-clock": 62298,
  "android-alert": 62299,
  "android-apps": 62300,
  "android-archive": 62153,
  "android-arrow-back": 62154,
  "android-arrow-down": 62301,
  "android-arrow-dropdown": 62303,
  "android-arrow-dropdown-circle": 62302,
  "android-arrow-dropleft": 62305,
  "android-arrow-dropleft-circle": 62304,
  "android-arrow-dropright": 62307,
  "android-arrow-dropright-circle": 62306,
  "android-arrow-dropup": 62309,
  "android-arrow-dropup-circle": 62308,
  "android-arrow-forward": 62223,
  "android-arrow-up": 62310,
  "android-attach": 62311,
  "android-bar": 62312,
  "android-bicycle": 62313,
  "android-boat": 62314,
  "android-bookmark": 62315,
  "android-bulb": 62316,
  "android-bus": 62317,
  "android-calendar": 62161,
  "android-call": 62162,
  "android-camera": 62163,
  "android-cancel": 62318,
  "android-car": 62319,
  "android-cart": 62320,
  "android-chat": 62164,
  "android-checkbox": 62324,
  "android-checkbox-blank": 62321,
  "android-checkbox-outline": 62323,
  "android-checkbox-outline-blank": 62322,
  "android-checkmark-circle": 62325,
  "android-clipboard": 62326,
  "android-close": 62167,
  "android-cloud": 62330,
  "android-cloud-circle": 62327,
  "android-cloud-done": 62328,
  "android-cloud-outline": 62329,
  "android-color-palette": 62331,
  "android-compass": 62332,
  "android-contact": 62168,
  "android-contacts": 62169,
  "android-contract": 62333,
  "android-create": 62334,
  "android-delete": 62335,
  "android-desktop": 62336,
  "android-document": 62337,
  "android-done": 62339,
  "android-done-all": 62338,
  "android-download": 62173,
  "android-drafts": 62340,
  "android-exit": 62341,
  "android-expand": 62342,
  "android-favorite": 62344,
  "android-favorite-outline": 62343,
  "android-film": 62345,
  "android-folder": 62176,
  "android-folder-open": 62346,
  "android-funnel": 62347,
  "android-globe": 62348,
  "android-hand": 62179,
  "android-hangout": 62349,
  "android-happy": 62350,
  "android-home": 62351,
  "android-image": 62180,
  "android-laptop": 62352,
  "android-list": 62353,
  "android-locate": 62185,
  "android-lock": 62354,
  "android-mail": 62187,
  "android-map": 62355,
  "android-menu": 62356,
  "android-microphone": 62188,
  "android-microphone-off": 62357,
  "android-more-horizontal": 62358,
  "android-more-vertical": 62359,
  "android-navigate": 62360,
  "android-notifications": 62363,
  "android-notifications-none": 62361,
  "android-notifications-off": 62362,
  "android-open": 62364,
  "android-options": 62365,
  "android-people": 62366,
  "android-person": 62368,
  "android-person-add": 62367,
  "android-phone-landscape": 62369,
  "android-phone-portrait": 62370,
  "android-pin": 62371,
  "android-plane": 62372,
  "android-playstore": 62192,
  "android-print": 62373,
  "android-radio-button-off": 62374,
  "android-radio-button-on": 62375,
  "android-refresh": 62376,
  "android-remove": 62196,
  "android-remove-circle": 62377,
  "android-restaurant": 62378,
  "android-sad": 62379,
  "android-search": 62197,
  "android-send": 62198,
  "android-settings": 62199,
  "android-share": 62200,
  "android-share-alt": 62380,
  "android-star": 62204,
  "android-star-half": 62381,
  "android-star-outline": 62382,
  "android-stopwatch": 62205,
  "android-subway": 62383,
  "android-sunny": 62384,
  "android-sync": 62385,
  "android-textsms": 62386,
  "android-time": 62387,
  "android-train": 62388,
  "android-unlock": 62389,
  "android-upload": 62390,
  "android-volume-down": 62391,
  "android-volume-mute": 62392,
  "android-volume-off": 62393,
  "android-volume-up": 62394,
  "android-walk": 62395,
  "android-warning": 62396,
  "android-watch": 62397,
  "android-wifi": 62213,
  "aperture": 62227,
  "archive": 61698,
  "arrow-down-a": 61699,
  "arrow-down-b": 61700,
  "arrow-down-c": 61701,
  "arrow-expand": 62046,
  "arrow-graph-down-left": 62047,
  "arrow-graph-down-right": 62048,
  "arrow-graph-up-left": 62049,
  "arrow-graph-up-right": 62050,
  "arrow-left-a": 61702,
  "arrow-left-b": 61703,
  "arrow-left-c": 61704,
  "arrow-move": 62051,
  "arrow-resize": 62052,
  "arrow-return-left": 62053,
  "arrow-return-right": 62054,
  "arrow-right-a": 61705,
  "arrow-right-b": 61706,
  "arrow-right-c": 61707,
  "arrow-shrink": 62055,
  "arrow-swap": 62056,
  "arrow-up-a": 61708,
  "arrow-up-b": 61709,
  "arrow-up-c": 61710,
  "asterisk": 62228,
  "at": 61711,
  "backspace": 62399,
  "backspace-outline": 62398,
  "bag": 61712,
  "battery-charging": 61713,
  "battery-empty": 61714,
  "battery-full": 61715,
  "battery-half": 61716,
  "battery-low": 61717,
  "beaker": 62057,
  "beer": 62058,
  "bluetooth": 61718,
  "bonfire": 62229,
  "bookmark": 62059,
  "bowtie": 62400,
  "briefcase": 62060,
  "bug": 62142,
  "calculator": 62061,
  "calendar": 61719,
  "camera": 61720,
  "card": 61721,
  "cash": 62230,
  "chatbox": 61723,
  "chatbox-working": 61722,
  "chatboxes": 61724,
  "chatbubble": 61726,
  "chatbubble-working": 61725,
  "chatbubbles": 61727,
  "checkmark": 61730,
  "checkmark-circled": 61728,
  "checkmark-round": 61729,
  "chevron-down": 61731,
  "chevron-left": 61732,
  "chevron-right": 61733,
  "chevron-up": 61734,
  "clipboard": 61735,
  "clock": 62062,
  "close": 61738,
  "close-circled": 61736,
  "close-round": 61737,
  "closed-captioning": 62231,
  "cloud": 61739,
  "code": 62065,
  "code-download": 62063,
  "code-working": 62064,
  "coffee": 62066,
  "compass": 62067,
  "compose": 61740,
  "connection-bars": 62068,
  "contrast": 62069,
  "crop": 62401,
  "cube": 62232,
  "disc": 61741,
  "document": 61743,
  "document-text": 61742,
  "drag": 61744,
  "earth": 62070,
  "easel": 62402,
  "edit": 62143,
  "egg": 62071,
  "eject": 61745,
  "email": 61746,
  "email-unread": 62403,
  "erlenmeyer-flask": 62405,
  "erlenmeyer-flask-bubbles": 62404,
  "eye": 61747,
  "eye-disabled": 62214,
  "female": 62072,
  "filing": 61748,
  "film-marker": 61749,
  "fireball": 62233,
  "flag": 62073,
  "flame": 62234,
  "flash": 61751,
  "flash-off": 61750,
  "folder": 61753,
  "fork": 62074,
  "fork-repo": 62144,
  "forward": 61754,
  "funnel": 62235,
  "gear-a": 61757,
  "gear-b": 61758,
  "grid": 61759,
  "hammer": 62075,
  "happy": 62236,
  "happy-outline": 62406,
  "headphone": 61760,
  "heart": 61761,
  "heart-broken": 62237,
  "help": 61763,
  "help-buoy": 62076,
  "help-circled": 61762,
  "home": 61764,
  "icecream": 62077,
  "image": 61767,
  "images": 61768,
  "information": 61770,
  "information-circled": 61769,
  "ionic": 61771,
  "ios-alarm": 62408,
  "ios-alarm-outline": 62407,
  "ios-albums": 62410,
  "ios-albums-outline": 62409,
  "ios-americanfootball": 62412,
  "ios-americanfootball-outline": 62411,
  "ios-analytics": 62414,
  "ios-analytics-outline": 62413,
  "ios-arrow-back": 62415,
  "ios-arrow-down": 62416,
  "ios-arrow-forward": 62417,
  "ios-arrow-left": 62418,
  "ios-arrow-right": 62419,
  "ios-arrow-thin-down": 62420,
  "ios-arrow-thin-left": 62421,
  "ios-arrow-thin-right": 62422,
  "ios-arrow-thin-up": 62423,
  "ios-arrow-up": 62424,
  "ios-at": 62426,
  "ios-at-outline": 62425,
  "ios-barcode": 62428,
  "ios-barcode-outline": 62427,
  "ios-baseball": 62430,
  "ios-baseball-outline": 62429,
  "ios-basketball": 62432,
  "ios-basketball-outline": 62431,
  "ios-bell": 62434,
  "ios-bell-outline": 62433,
  "ios-body": 62436,
  "ios-body-outline": 62435,
  "ios-bolt": 62438,
  "ios-bolt-outline": 62437,
  "ios-book": 62440,
  "ios-book-outline": 62439,
  "ios-bookmarks": 62442,
  "ios-bookmarks-outline": 62441,
  "ios-box": 62444,
  "ios-box-outline": 62443,
  "ios-briefcase": 62446,
  "ios-briefcase-outline": 62445,
  "ios-browsers": 62448,
  "ios-browsers-outline": 62447,
  "ios-calculator": 62450,
  "ios-calculator-outline": 62449,
  "ios-calendar": 62452,
  "ios-calendar-outline": 62451,
  "ios-camera": 62454,
  "ios-camera-outline": 62453,
  "ios-cart": 62456,
  "ios-cart-outline": 62455,
  "ios-chatboxes": 62458,
  "ios-chatboxes-outline": 62457,
  "ios-chatbubble": 62460,
  "ios-chatbubble-outline": 62459,
  "ios-checkmark": 62463,
  "ios-checkmark-empty": 62461,
  "ios-checkmark-outline": 62462,
  "ios-circle-filled": 62464,
  "ios-circle-outline": 62465,
  "ios-clock": 62467,
  "ios-clock-outline": 62466,
  "ios-close": 62470,
  "ios-close-empty": 62468,
  "ios-close-outline": 62469,
  "ios-cloud": 62476,
  "ios-cloud-download": 62472,
  "ios-cloud-download-outline": 62471,
  "ios-cloud-outline": 62473,
  "ios-cloud-upload": 62475,
  "ios-cloud-upload-outline": 62474,
  "ios-cloudy": 62480,
  "ios-cloudy-night": 62478,
  "ios-cloudy-night-outline": 62477,
  "ios-cloudy-outline": 62479,
  "ios-cog": 62482,
  "ios-cog-outline": 62481,
  "ios-color-filter": 62484,
  "ios-color-filter-outline": 62483,
  "ios-color-wand": 62486,
  "ios-color-wand-outline": 62485,
  "ios-compose": 62488,
  "ios-compose-outline": 62487,
  "ios-contact": 62490,
  "ios-contact-outline": 62489,
  "ios-copy": 62492,
  "ios-copy-outline": 62491,
  "ios-crop": 62494,
  "ios-crop-strong": 62493,
  "ios-download": 62496,
  "ios-download-outline": 62495,
  "ios-drag": 62497,
  "ios-email": 62499,
  "ios-email-outline": 62498,
  "ios-eye": 62501,
  "ios-eye-outline": 62500,
  "ios-fastforward": 62503,
  "ios-fastforward-outline": 62502,
  "ios-filing": 62505,
  "ios-filing-outline": 62504,
  "ios-film": 62507,
  "ios-film-outline": 62506,
  "ios-flag": 62509,
  "ios-flag-outline": 62508,
  "ios-flame": 62511,
  "ios-flame-outline": 62510,
  "ios-flask": 62513,
  "ios-flask-outline": 62512,
  "ios-flower": 62515,
  "ios-flower-outline": 62514,
  "ios-folder": 62517,
  "ios-folder-outline": 62516,
  "ios-football": 62519,
  "ios-football-outline": 62518,
  "ios-game-controller-a": 62521,
  "ios-game-controller-a-outline": 62520,
  "ios-game-controller-b": 62523,
  "ios-game-controller-b-outline": 62522,
  "ios-gear": 62525,
  "ios-gear-outline": 62524,
  "ios-glasses": 62527,
  "ios-glasses-outline": 62526,
  "ios-grid-view": 62529,
  "ios-grid-view-outline": 62528,
  "ios-heart": 62531,
  "ios-heart-outline": 62530,
  "ios-help": 62534,
  "ios-help-empty": 62532,
  "ios-help-outline": 62533,
  "ios-home": 62536,
  "ios-home-outline": 62535,
  "ios-infinite": 62538,
  "ios-infinite-outline": 62537,
  "ios-information": 62541,
  "ios-information-empty": 62539,
  "ios-information-outline": 62540,
  "ios-ionic-outline": 62542,
  "ios-keypad": 62544,
  "ios-keypad-outline": 62543,
  "ios-lightbulb": 62546,
  "ios-lightbulb-outline": 62545,
  "ios-list": 62548,
  "ios-list-outline": 62547,
  "ios-location": 62550,
  "ios-location-outline": 62549,
  "ios-locked": 62552,
  "ios-locked-outline": 62551,
  "ios-loop": 62554,
  "ios-loop-strong": 62553,
  "ios-medical": 62556,
  "ios-medical-outline": 62555,
  "ios-medkit": 62558,
  "ios-medkit-outline": 62557,
  "ios-mic": 62561,
  "ios-mic-off": 62559,
  "ios-mic-outline": 62560,
  "ios-minus": 62564,
  "ios-minus-empty": 62562,
  "ios-minus-outline": 62563,
  "ios-monitor": 62566,
  "ios-monitor-outline": 62565,
  "ios-moon": 62568,
  "ios-moon-outline": 62567,
  "ios-more": 62570,
  "ios-more-outline": 62569,
  "ios-musical-note": 62571,
  "ios-musical-notes": 62572,
  "ios-navigate": 62574,
  "ios-navigate-outline": 62573,
  "ios-nutrition": 62576,
  "ios-nutrition-outline": 62575,
  "ios-paper": 62578,
  "ios-paper-outline": 62577,
  "ios-paperplane": 62580,
  "ios-paperplane-outline": 62579,
  "ios-partlysunny": 62582,
  "ios-partlysunny-outline": 62581,
  "ios-pause": 62584,
  "ios-pause-outline": 62583,
  "ios-paw": 62586,
  "ios-paw-outline": 62585,
  "ios-people": 62588,
  "ios-people-outline": 62587,
  "ios-person": 62590,
  "ios-person-outline": 62589,
  "ios-personadd": 62592,
  "ios-personadd-outline": 62591,
  "ios-photos": 62594,
  "ios-photos-outline": 62593,
  "ios-pie": 62596,
  "ios-pie-outline": 62595,
  "ios-pint": 62598,
  "ios-pint-outline": 62597,
  "ios-play": 62600,
  "ios-play-outline": 62599,
  "ios-plus": 62603,
  "ios-plus-empty": 62601,
  "ios-plus-outline": 62602,
  "ios-pricetag": 62605,
  "ios-pricetag-outline": 62604,
  "ios-pricetags": 62607,
  "ios-pricetags-outline": 62606,
  "ios-printer": 62609,
  "ios-printer-outline": 62608,
  "ios-pulse": 62611,
  "ios-pulse-strong": 62610,
  "ios-rainy": 62613,
  "ios-rainy-outline": 62612,
  "ios-recording": 62615,
  "ios-recording-outline": 62614,
  "ios-redo": 62617,
  "ios-redo-outline": 62616,
  "ios-refresh": 62620,
  "ios-refresh-empty": 62618,
  "ios-refresh-outline": 62619,
  "ios-reload": 62621,
  "ios-reverse-camera": 62623,
  "ios-reverse-camera-outline": 62622,
  "ios-rewind": 62625,
  "ios-rewind-outline": 62624,
  "ios-rose": 62627,
  "ios-rose-outline": 62626,
  "ios-search": 62629,
  "ios-search-strong": 62628,
  "ios-settings": 62631,
  "ios-settings-strong": 62630,
  "ios-shuffle": 62633,
  "ios-shuffle-strong": 62632,
  "ios-skipbackward": 62635,
  "ios-skipbackward-outline": 62634,
  "ios-skipforward": 62637,
  "ios-skipforward-outline": 62636,
  "ios-snowy": 62638,
  "ios-speedometer": 62640,
  "ios-speedometer-outline": 62639,
  "ios-star": 62643,
  "ios-star-half": 62641,
  "ios-star-outline": 62642,
  "ios-stopwatch": 62645,
  "ios-stopwatch-outline": 62644,
  "ios-sunny": 62647,
  "ios-sunny-outline": 62646,
  "ios-telephone": 62649,
  "ios-telephone-outline": 62648,
  "ios-tennisball": 62651,
  "ios-tennisball-outline": 62650,
  "ios-thunderstorm": 62653,
  "ios-thunderstorm-outline": 62652,
  "ios-time": 62655,
  "ios-time-outline": 62654,
  "ios-timer": 62657,
  "ios-timer-outline": 62656,
  "ios-toggle": 62659,
  "ios-toggle-outline": 62658,
  "ios-trash": 62661,
  "ios-trash-outline": 62660,
  "ios-undo": 62663,
  "ios-undo-outline": 62662,
  "ios-unlocked": 62665,
  "ios-unlocked-outline": 62664,
  "ios-upload": 62667,
  "ios-upload-outline": 62666,
  "ios-videocam": 62669,
  "ios-videocam-outline": 62668,
  "ios-volume-high": 62670,
  "ios-volume-low": 62671,
  "ios-wineglass": 62673,
  "ios-wineglass-outline": 62672,
  "ios-world": 62675,
  "ios-world-outline": 62674,
  "ipad": 61945,
  "iphone": 61946,
  "ipod": 61947,
  "jet": 62101,
  "key": 62102,
  "knife": 62103,
  "laptop": 61948,
  "leaf": 61949,
  "levels": 62104,
  "lightbulb": 62105,
  "link": 61950,
  "load-a": 62106,
  "load-b": 62107,
  "load-c": 62108,
  "load-d": 62109,
  "location": 61951,
  "lock-combination": 62676,
  "locked": 61952,
  "log-in": 62110,
  "log-out": 62111,
  "loop": 61953,
  "magnet": 62112,
  "male": 62113,
  "man": 61954,
  "map": 61955,
  "medkit": 62114,
  "merge": 62271,
  "mic-a": 61956,
  "mic-b": 61957,
  "mic-c": 61958,
  "minus": 61961,
  "minus-circled": 61959,
  "minus-round": 61960,
  "model-s": 62145,
  "monitor": 61962,
  "more": 61963,
  "mouse": 62272,
  "music-note": 61964,
  "navicon": 61966,
  "navicon-round": 61965,
  "navigate": 62115,
  "network": 62273,
  "no-smoking": 62146,
  "nuclear": 62116,
  "outlet": 62274,
  "paintbrush": 62677,
  "paintbucket": 62678,
  "paper-airplane": 62147,
  "paperclip": 61967,
  "pause": 61968,
  "person": 61971,
  "person-add": 61969,
  "person-stalker": 61970,
  "pie-graph": 62117,
  "pin": 62118,
  "pinpoint": 62119,
  "pizza": 62120,
  "plane": 61972,
  "planet": 62275,
  "play": 61973,
  "playstation": 62218,
  "plus": 61976,
  "plus-circled": 61974,
  "plus-round": 61975,
  "podium": 62276,
  "pound": 61977,
  "power": 62121,
  "pricetag": 62122,
  "pricetags": 62123,
  "printer": 61978,
  "pull-request": 62277,
  "qr-scanner": 62278,
  "quote": 62279,
  "radio-waves": 62124,
  "record": 61979,
  "refresh": 61980,
  "reply": 61982,
  "reply-all": 61981,
  "ribbon-a": 62280,
  "ribbon-b": 62281,
  "sad": 62282,
  "sad-outline": 62679,
  "scissors": 62283,
  "search": 61983,
  "settings": 62125,
  "share": 61984,
  "shuffle": 61985,
  "skip-backward": 61986,
  "skip-forward": 61987,
  "social-android": 61989,
  "social-android-outline": 61988,
  "social-angular": 62681,
  "social-angular-outline": 62680,
  "social-apple": 61991,
  "social-apple-outline": 61990,
  "social-bitcoin": 62127,
  "social-bitcoin-outline": 62126,
  "social-buffer": 61993,
  "social-buffer-outline": 61992,
  "social-chrome": 62683,
  "social-chrome-outline": 62682,
  "social-codepen": 62685,
  "social-codepen-outline": 62684,
  "social-css3": 62687,
  "social-css3-outline": 62686,
  "social-designernews": 61995,
  "social-designernews-outline": 61994,
  "social-dribbble": 61997,
  "social-dribbble-outline": 61996,
  "social-dropbox": 61999,
  "social-dropbox-outline": 61998,
  "social-euro": 62689,
  "social-euro-outline": 62688,
  "social-facebook": 62001,
  "social-facebook-outline": 62000,
  "social-foursquare": 62285,
  "social-foursquare-outline": 62284,
  "social-freebsd-devil": 62148,
  "social-github": 62003,
  "social-github-outline": 62002,
  "social-google": 62287,
  "social-google-outline": 62286,
  "social-googleplus": 62005,
  "social-googleplus-outline": 62004,
  "social-hackernews": 62007,
  "social-hackernews-outline": 62006,
  "social-html5": 62691,
  "social-html5-outline": 62690,
  "social-instagram": 62289,
  "social-instagram-outline": 62288,
  "social-javascript": 62693,
  "social-javascript-outline": 62692,
  "social-linkedin": 62009,
  "social-linkedin-outline": 62008,
  "social-markdown": 62694,
  "social-nodejs": 62695,
  "social-octocat": 62696,
  "social-pinterest": 62129,
  "social-pinterest-outline": 62128,
  "social-python": 62697,
  "social-reddit": 62011,
  "social-reddit-outline": 62010,
  "social-rss": 62013,
  "social-rss-outline": 62012,
  "social-sass": 62698,
  "social-skype": 62015,
  "social-skype-outline": 62014,
  "social-snapchat": 62700,
  "social-snapchat-outline": 62699,
  "social-tumblr": 62017,
  "social-tumblr-outline": 62016,
  "social-tux": 62149,
  "social-twitch": 62702,
  "social-twitch-outline": 62701,
  "social-twitter": 62019,
  "social-twitter-outline": 62018,
  "social-usd": 62291,
  "social-usd-outline": 62290,
  "social-vimeo": 62021,
  "social-vimeo-outline": 62020,
  "social-whatsapp": 62704,
  "social-whatsapp-outline": 62703,
  "social-windows": 62023,
  "social-windows-outline": 62022,
  "social-wordpress": 62025,
  "social-wordpress-outline": 62024,
  "social-yahoo": 62027,
  "social-yahoo-outline": 62026,
  "social-yen": 62706,
  "social-yen-outline": 62705,
  "social-youtube": 62029,
  "social-youtube-outline": 62028,
  "soup-can": 62708,
  "soup-can-outline": 62707,
  "speakerphone": 62130,
  "speedometer": 62131,
  "spoon": 62132,
  "star": 62030,
  "stats-bars": 62133,
  "steam": 62219,
  "stop": 62031,
  "thermometer": 62134,
  "thumbsdown": 62032,
  "thumbsup": 62033,
  "toggle": 62293,
  "toggle-filled": 62292,
  "transgender": 62709,
  "trash-a": 62034,
  "trash-b": 62035,
  "trophy": 62294,
  "tshirt": 62711,
  "tshirt-outline": 62710,
  "umbrella": 62135,
  "university": 62295,
  "unlocked": 62036,
  "upload": 62037,
  "usb": 62136,
  "videocamera": 62038,
  "volume-high": 62039,
  "volume-low": 62040,
  "volume-medium": 62041,
  "volume-mute": 62042,
  "wand": 62296,
  "waterdrop": 62043,
  "wifi": 62044,
  "wineglass": 62137,
  "woman": 62045,
  "wrench": 62138,
  "xbox": 62220
};

var Ionicons = createIconSet(glyphMap, 'Ionicons', 'Ionicons.ttf');

module.exports = Ionicons;
module.exports.glyphMap = glyphMap;

